==> OmegaT_2.0.5_02_Source.zip: src/org/omegat/util/gui/ResourcesUtil.java <==
/**************************************************************************
 OmegaT - Computer Assisted Translation (CAT) tool 
          with fuzzy matching, translation memory, keyword search, 
          glossaries, and translation leveraging into updated projects.

 Copyright (C) 2008 Alex Buloichik
               Home page: http://www.omegat.org/
               Support center: http://groups.yahoo.com/group/OmegaT/

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **************************************************************************/

package org.omegat.util.gui;

import java.net.URL;

import javax.swing.ImageIcon;

/**
 * Utils for load resources from classpath.
 * 
 * @author Alex Buloichik (alex73mail@gmail.com)
 */
public class ResourcesUtil {
    /**
     * Load icon.
     * 
     * @param resourceName
     *                resource name
     */
    public static ImageIcon getIcon(final String resourceName) {
        URL resourceURL = ResourcesUtil.class.getResource(resourceName);
        return new ImageIcon(resourceURL);
    }
}

==> OmegaT_2.6.3_01_Source.zip: src/org/omegat/util/gui/ResourcesUtil.java <==
/**************************************************************************
 OmegaT - Computer Assisted Translation (CAT) tool 
          with fuzzy matching, translation memory, keyword search, 
          glossaries, and translation leveraging into updated projects.

 Copyright (C) 2008 Alex Buloichik
               Home page: http://www.omegat.org/
               Support center: http://groups.yahoo.com/group/OmegaT/

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 **************************************************************************/

package org.omegat.util.gui;

import java.net.URL;

import javax.swing.ImageIcon;

/**
 * Utils for load resources from classpath.
 * 
 * @author Alex Buloichik (alex73mail@gmail.com)
 */
public class ResourcesUtil {
    /**
     * Load icon.
     * 
     * @param resourceName
     *            resource name
     */
    public static ImageIcon getIcon(final String resourceName) {
        URL resourceURL = ResourcesUtil.class.getResource(resourceName);
        return new ImageIcon(resourceURL);
    }
}
